/*                      - IOH83067.H -                                  */
/*                                                                      */
/*      (c) Copyright Hitachi Micro Systems Europe Ltd. (HMSE), 1998    */
/*   					                               */
/*                                                                      */
/*      Revision of this file:  $Revision: 1.0 $                       */
/*                                                                      */


#ifndef _IOH83067_INCLUDED
#define _IOH83067_INCLUDED

#define ICC_UCHAR       *(volatile unsigned char *)
#define ICC_USHORT      *(volatile unsigned short *)
#define ICC_ULONG       *(volatile unsigned long *)
#define H8interrupt ((volatile unsigned long *) 0x20000) 
#define H8proc = 0x5a000000 + (unsigned long) 


/*
                H8S/3067 Special Function Registers
*/



/*                  System control
                    --------------
*/
#define MDCR        (ICC_UCHAR   (0xFFFEE011))  /* Mode control            */
#define SYSCR       (ICC_UCHAR   (0xFFFEE012))  /* System control          */
#define DIVCR       (ICC_UCHAR   (0xFFFEE01B))  /* Serial/Timer control    */
#define MSTPCRH     (ICC_UCHAR   (0xFFFEE01C))  /* Module stop control  H  */
#define MSTPCRL     (ICC_UCHAR   (0xFFFEE01D))  /* Module stop control  L  */



/*          Interrupt Controller Registers 
                    ------------------------------
*/
#define ISCR        (ICC_UCHAR   (0xFFFEE014))  /* IRQ sense control H     */
#define IER         (ICC_UCHAR   (0xFFFEE015))  /* IRQ enable              */
#define ISR         (ICC_UCHAR   (0xFFFEE016))  /* IRQ status              */
#define IPRA        (ICC_UCHAR   (0xFFFEE018))  /* Interrupt control A     */
#define IPRB        (ICC_UCHAR   (0xFFFEE019))  /* Interrupt control B     */



/*                  Bus controller
                    --------------
*/
#define BRCR        (ICC_UCHAR   (0xFFFEE013))  /* Bus width control       */
#define CSCR        (ICC_UCHAR   (0xFFFEE01F))  /* Wait state control      */
#define ABWCR       (ICC_UCHAR   (0xFFFEE020))  /* Wait state control      */
#define ASTCR       (ICC_UCHAR   (0xFFFEE021))  /* Wait state control      */
#define WCRH        (ICC_UCHAR   (0xFFFEE022))  /* Wait state control      */
#define WCRL        (ICC_UCHAR   (0xFFFEE023))  /* Wait state control      */
#define BCR         (ICC_UCHAR   (0xFFFEE024))  /* Bus width control       */



/*                  Some I/O ports....  
                    --------------------
*/
#define P1DDR       (ICC_UCHAR   (0xFFFEE000))  /* Port 1 data direction    */
#define P1DR        (ICC_UCHAR   (0xFFFFFFD0))  /* Port 1 data              */

#define P2DDR       (ICC_UCHAR   (0xFFFEE001))  /* Port 2 data direction    */
#define P2DR        (ICC_UCHAR   (0xFFFFFFD1))  /* Port 2 data              */
#define P2PCR       (ICC_UCHAR   (0xFFFEE03C))  /* Port 2               */

#define P3DDR       (ICC_UCHAR   (0xFFFEE002))  /* Port 3 data direction    */
#define P3DR        (ICC_UCHAR   (0xFFFFFFD2))  /* Port 3 data              */

#define P4DDR       (ICC_UCHAR   (0xFFFEE003))  /* Port 4 data direction    */
#define P4DR        (ICC_UCHAR   (0xFFFFFFD3))  /* Port 4 data              */
#define P4PCR       (ICC_UCHAR   (0xFFFEE03E))  /* Port 2               */

#define P5DDR       (ICC_UCHAR   (0xFFFEE004))  /* Port 5 data direction    */
#define P5DR        (ICC_UCHAR   (0xFFFFFFD4))  /* Port 5 data              */
#define P5PCR       (ICC_UCHAR   (0xFFFEE03F))  /* Port 2               */

#define P6DDR       (ICC_UCHAR   (0xFFFEE005))  /* Port 6 data direction    */
#define P6DR        (ICC_UCHAR   (0xFFFFFFD5))  /* Port 6 data              */

#define P7DR        (ICC_UCHAR   (0xFFFFFFD6))  /* Port 6 data              */

#define P8DDR       (ICC_UCHAR   (0xFFFEE007))  /* Port 8 data direction    */
#define P8DR        (ICC_UCHAR   (0xFFFFFFD7))  /* Port 8 data              */

#define P9DDR       (ICC_UCHAR   (0xFFFEE008))  /* Port 9 data direction    */
#define P9DR        (ICC_UCHAR   (0xFFFFFFD8))  /* Port 9 data              */

#define PADDR       (ICC_UCHAR   (0xFFFEE009))  /* Port A data direction    */
#define PADR        (ICC_UCHAR   (0xFFFFFFD9))  /* Port A output data       */

#define PBDDR       (ICC_UCHAR   (0xFFFEE00A))  /* Port B data direction    */
#define PBDR        (ICC_UCHAR   (0xFFFFFFDA))  /* Port B output data       */



/*                  8-bit timers
                    ------------
*/
#define TM_TCR0     (ICC_UCHAR   (0xFFFFFF80))  /* Timer control      ch 0 */
#define TM_TCSR0    (ICC_UCHAR   (0xFFFFFF82))  /* Timer cntrl/status ch 0 */
#define TM_TCORA0   (ICC_UCHAR   (0xFFFFFF84))  /* Timer constant A0  ch 0 */
#define TM_TCORB0   (ICC_UCHAR   (0xFFFFFF86))  /* Timer constant B0  ch 0 */
#define TM_TCNT0    (ICC_UCHAR   (0xFFFFFF88))  /* Timer counter      ch 0 */

#define TM_TCR1     (ICC_UCHAR   (0xFFFFFF81))  /* Timer control      ch 1 */
#define TM_TCSR1    (ICC_UCHAR   (0xFFFFFF83))  /* Timer cntrl/status ch 1 */
#define TM_TCORA1   (ICC_UCHAR   (0xFFFFFF85))  /* Timer constant A1  ch 1 */
#define TM_TCORB1   (ICC_UCHAR   (0xFFFFFF87))  /* Timer constant B1  ch 1 */
#define TM_TCNT1    (ICC_UCHAR   (0xFFFFFF89))  /* Timer counter      ch 1 */

#define TM_TCR2     (ICC_UCHAR   (0xFFFFFF90))  /* Timer control      ch 0 */
#define TM_TCSR2    (ICC_UCHAR   (0xFFFFFF92))  /* Timer cntrl/status ch 0 */
#define TM_TCORA2   (ICC_UCHAR   (0xFFFFFF94))  /* Timer constant A0  ch 0 */
#define TM_TCORB2   (ICC_UCHAR   (0xFFFFFF96))  /* Timer constant B0  ch 0 */
#define TM_TCNT2    (ICC_UCHAR   (0xFFFFFF98))  /* Timer counter      ch 0 */

#define TM_TCR3     (ICC_UCHAR   (0xFFFFFF91))  /* Timer control      ch 1 */
#define TM_TCSR3    (ICC_UCHAR   (0xFFFFFF93))  /* Timer cntrl/status ch 1 */
#define TM_TCORA3   (ICC_UCHAR   (0xFFFFFF95))  /* Timer constant A1  ch 1 */
#define TM_TCORB3   (ICC_UCHAR   (0xFFFFFF97))  /* Timer constant B1  ch 1 */
#define TM_TCNT3    (ICC_UCHAR   (0xFFFFFF99))  /* Timer counter      ch 1 */



/*                  16-bit free running timer
                    -------------------------
*/
#define FRT_TSTR    (ICC_UCHAR   (0xFFFFFF60))  /* Timer interrupt enable    */
#define FRT_TSNC    (ICC_UCHAR   (0xFFFFFF61))  /* Timer cntrl/status        */
#define FRT_TMDR    (ICC_UCHAR   (0xFFFFFF62))  /* Free running counter      */
#define FRT_TOLR    (ICC_UCHAR   (0xFFFFFF63))  /* Output compare A          */
#define FRT_TISRA   (ICC_UCHAR   (0xFFFFFF64))  /* Output compare B          */
#define FRT_TISRB   (ICC_UCHAR   (0xFFFFFF65))  /* Timer control             */
#define FRT_TISRC   (ICC_UCHAR   (0xFFFFFF66))  /* Timer output compare
                                                   control*/
#define FRT_TCR0    (ICC_UCHAR   (0xFFFFFF68))  /* Input capture A           */
#define FRT_TIOR0   (ICC_UCHAR   (0xFFFFFF69))  /* Input capture B           */
#define FRT_TCNT0H  (ICC_UCHAR   (0xFFFFFF6A))  /* Input capture C           */
#define FRT_TCNT0L  (ICC_UCHAR   (0xFFFFFF6B))  /* Input capture D           */
#define FRT_GRA0H   (ICC_UCHAR   (0xFFFFFF6C))  /* Output compare AR         */
#define FRT_GRA0L   (ICC_UCHAR   (0xFFFFFF6D))  /* Output compare AF         */
#define FRT_GRB0H   (ICC_UCHAR   (0xFFFFFF6E))  /* Output compare DM         */
#define FRT_GRB0L   (ICC_UCHAR   (0xFFFFFF6F))  /* Output compare DM         */

#define FRT_TCR1    (ICC_UCHAR   (0xFFFFFF70))  /* Input capture A           */
#define FRT_TIOR1   (ICC_UCHAR   (0xFFFFFF71))  /* Input capture B           */
#define FRT_TCNT1H  (ICC_UCHAR   (0xFFFFFF72))  /* Input capture C           */
#define FRT_TCNT1L  (ICC_UCHAR   (0xFFFFFF73))  /* Input capture D           */
#define FRT_GRA1H   (ICC_UCHAR   (0xFFFFFF74))  /* Output compare AR         */
#define FRT_GRA1L   (ICC_UCHAR   (0xFFFFFF75))  /* Output compare AF         */
#define FRT_GRB1H   (ICC_UCHAR   (0xFFFFFF76))  /* Output compare DM         */
#define FRT_GRB1L   (ICC_UCHAR   (0xFFFFFF77))  /* Output compare DM         */

#define FRT_TCR2    (ICC_UCHAR   (0xFFFFFF78))  /* Input capture A           */
#define FRT_TIOR2   (ICC_UCHAR   (0xFFFFFF79))  /* Input capture B           */
#define FRT_TCNT2H  (ICC_UCHAR   (0xFFFFFF7A))  /* Input capture C           */
#define FRT_TCNT2L  (ICC_UCHAR   (0xFFFFFF7B))  /* Input capture D           */
#define FRT_GRA2H   (ICC_UCHAR   (0xFFFFFF7C))  /* Output compare AR         */
#define FRT_GRA2L   (ICC_UCHAR   (0xFFFFFF7D))  /* Output compare AF         */
#define FRT_GRB2H   (ICC_UCHAR   (0xFFFFFF7E))  /* Output compare DM         */
#define FRT_GRB2L   (ICC_UCHAR   (0xFFFFFF7F))  /* Output compare DM         */



/*                  TPC
                    ---
*/
#define TPC_TPMR    (ICC_UCHAR   (0xFFFFFFA0))  /* D/A control               */
#define TPC_TPCR    (ICC_UCHAR   (0xFFFFFFA1))  /* D/A data A high           */
#define TPC_NDERB   (ICC_UCHAR   (0xFFFFFFA2))  /* D/A data A low            */
#define TPC_NDERA   (ICC_UCHAR   (0xFFFFFFA3))  /* D/A data B high           */
#define TPC_NDRB3   (ICC_UCHAR   (0xFFFFFFA4))  /* D/A data B low            */
#define TPC_NDRA1   (ICC_UCHAR   (0xFFFFFFA5))  /* D/A counter high          */
#define TPC_NDRB2   (ICC_UCHAR   (0xFFFFFFA6))  /* D/A counter low           */
#define TPC_NDRA0   (ICC_UCHAR   (0xFFFFFFA7))  /* D/A counter low           */



/*                  Serial communication interface
                    ------------------------------
*/
#define SCI_SMR0    (ICC_UCHAR   (0xFFFFFFB0))  /* Serial mode         ch 0 */
#define SCI_BRR0    (ICC_UCHAR   (0xFFFFFFB1))  /* Bit rate            ch 0 */
#define SCI_SCR0    (ICC_UCHAR   (0xFFFFFFB2))  /* Serial control      ch 0 */
#define SCI_TDR0    (ICC_UCHAR   (0xFFFFFFB3))  /* Transmit data       ch 0 */
#define SCI_SSR0    (ICC_UCHAR   (0xFFFFFFB4))  /* Serial status       ch 0 */
#define SCI_RDR0    (ICC_UCHAR   (0xFFFFFFB5))  /* Receive data        ch 0 */
#define SCI_SCMR0   (ICC_UCHAR   (0xFFFFFFB6))  /* Serial interface 
                                                   mode ch 0 */

#define SCI_SMR1    (ICC_UCHAR   (0xFFFFFFB8))  /* Serial mode         ch 1 */
#define SCI_BRR1    (ICC_UCHAR   (0xFFFFFFB9))  /* Bit rate            ch 1 */
#define SCI_SCR1    (ICC_UCHAR   (0xFFFFFFBA))  /* Serial control      ch 1 */
#define SCI_TDR1    (ICC_UCHAR   (0xFFFFFFBB))  /* Transmit data       ch 1 */
#define SCI_SSR1    (ICC_UCHAR   (0xFFFFFFBC))  /* Serial status       ch 1 */
#define SCI_RDR1    (ICC_UCHAR   (0xFFFFFFBD))  /* Receive data        ch 1 */
#define SCI_SCMR1   (ICC_UCHAR   (0xFFFFFFBE))  /* Serial interface
                                                   mode ch 1 */

#define SCI_SMR2    (ICC_UCHAR   (0xFFFFFFC0))  /* Serial mode         ch 2 */
#define SCI_BRR2    (ICC_UCHAR   (0xFFFFFFC1))  /* Bit rate            ch 2 */
#define SCI_SCR2    (ICC_UCHAR   (0xFFFFFFC2))  /* Serial control      ch 2 */
#define SCI_TDR2    (ICC_UCHAR   (0xFFFFFFC3))  /* Transmit data       ch 2 */
#define SCI_SSR2    (ICC_UCHAR   (0xFFFFFFC4))  /* Serial status       ch 2 */
#define SCI_RDR2    (ICC_UCHAR   (0xFFFFFFC5))  /* Receive data        ch 2 */
#define SCI_SCMR2   (ICC_UCHAR   (0xFFFFFFC6))  /* Serial interface
                                                  control */


/*                  D/A converter
                    -------------
*/
#define DADR0       (ICC_UCHAR   (0xFFFFFF9C))  /* Data register 0         */
#define DADR1       (ICC_UCHAR   (0xFFFFFF9D))  /* Data register 1         */
#define DACR        (ICC_UCHAR   (0xFFFFFF9E))  /* Control                 */
#define DASTCR      (ICC_UCHAR   (0xFFFEE01A))  /* Control                 */



/*                  A/D converter
                    -------------
*/
#define ADDRAH      (ICC_UCHAR   (0xFFFFFFE0))  /* Data register A high    */
#define ADDRAL      (ICC_UCHAR   (0xFFFFFFE1))  /* Data register A low     */
#define ADDRBH      (ICC_UCHAR   (0xFFFFFFE2))  /* Data register B high    */
#define ADDRBL      (ICC_UCHAR   (0xFFFFFFE3))  /* Data register B low     */
#define ADDRCH      (ICC_UCHAR   (0xFFFFFFE4))  /* Data register C high    */
#define ADDRCL      (ICC_UCHAR   (0xFFFFFFE5))  /* Data register C low     */
#define ADDRDH      (ICC_UCHAR   (0xFFFFFFE6))  /* Data register D high    */
#define ADDRDL      (ICC_UCHAR   (0xFFFFFFE7))  /* Data register D low     */

#define ADCSR       (ICC_UCHAR   (0xFFFFFFE8))  /* Control/status          */
#define ADCR        (ICC_UCHAR   (0xFFFFFFE9))  /* Control                 */



/*                  Watchdog timer
                    --------------
*/
#define WDT_TCSR_R    (ICC_UCHAR  (0xFFFFFF8C))  /* Timer control (read)  ch0 */
#define WDT_TCSR_W    (ICC_USHORT (0xFFFFFF8C))  /* Timer control (write) ch0 */
#define WDT_TCNT_R    (ICC_UCHAR  (0xFFFFFF8D))  /* Timer counter (read)  ch0 */
#define WDT_TCNT_W    (ICC_USHORT (0xFFFFFF8C))  /* Timer counter (write) ch0 */
#define WDT_RSTCSR_R  (ICC_UCHAR  (0xFFFFFF8F))  /* Timer counter (write) ch0 */
#define WDT_RSTCSR_W  (ICC_USHORT (0xFFFFFF8E))  /* Timer counter (write) ch0 */


/*                  Flash memory
                    ------------
*/
#define FLMCR        (ICC_UCHAR (0xFFFEE030)) /* Flash memory control 1    */
#define FLMSR        (ICC_UCHAR (0xFFFFFF4D)) /* Flash memory control 2    */
#define ERB          (ICC_UCHAR (0xFFFEE032)) /* Erase block 1             */
#define RAMCR        (ICC_UCHAR (0xFFFFFF47)) /* Erase block 2             */





/*
        H8S/2144 Non Maskable Interrupt Vectors
*/

#define RESET                   0x00

#define NMI                     7

#define TRAP0                   8
#define TRAP1                   9
#define TRAP2                   10
#define TRAP3                   11

#define IRQ_0                   12
#define IRQ_1                   13
#define IRQ_2                   14
#define IRQ_3                   15
#define IRQ_4                   16
#define IRQ_5                   17

#define WDT_WOVI                20

#define DRAM_CMI                21

#define ADI                     23

#define FRT_IMIA0               24
#define FRT_IMIB0               25
#define FRT_OVI0                26

#define FRT_IMIA1               28
#define FRT_IMIB1               29
#define FRT_OVI1                30

#define FRT_IMIA2               32
#define FRT_IMIB2               33
#define FRT_OVI2                34

#define TM_CMIA0                36
#define TM_CMIB0                37
#define TM_CMIA1B1              38
#define TM_OVI01                39

#define TM_CMIA2                40
#define TM_CMIB2                41
#define TM_CMIA3B3              42
#define TM_OVI23                43

#define SCI_ERI0                52
#define SCI_RXI0                53
#define SCI_TXI0                54
#define SCI_TEI0                55

#define SCI_ERI1                56
#define SCI_RXI1                57
#define SCI_TXI1                58
#define SCI_TEI1                59

#define SCI_ERI2                60
#define SCI_RXI2                61
#define SCI_TXI2                62
#define SCI_TEI2                63

#endif

/* EOF */
